
.. toctree::
   :hidden:
   :glob:

   README <readme>
   Examples <examples/index>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>

.. include:: ../README.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`